@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Administration avec la console web de Cockpit"
  ],
+ "Administrative access": [
+  null,
+  "Accès administrateur"
+ ],
  "Advanced TCA": [
   null,
   "TCA avancé"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Documentation des rôles Ansible"
  ],
+ "Authenticate": [
+  null,
+  "S’authentifier"
+ ],
  "Authentication": [
   null,
   "Authentification"
@@ -498,6 +506,18 @@ window.cockpit_po = {
   null,
   "En savoir plus"
  ],
+ "Limit access": [
+  null,
+  "Limiter l’accès"
+ ],
+ "Limited access": [
+  null,
+  "Accès limité"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "Le mode accès limité restreint les privilèges d’administration. Certaines parties de la console web auront des fonctionnalités réduites."
+ ],
  "Loading system modifications...": [
   null,
   "Chargement des modifications système..."
@@ -558,6 +578,10 @@ window.cockpit_po = {
   null,
   "Message aux utilisateurs connectés"
  ],
+ "Method": [
+  null,
+  "Méthode"
+ ],
  "Mini PC": [
   null,
   "Mini PC"
@@ -594,6 +618,10 @@ window.cockpit_po = {
   null,
   "Aucun délai"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  "Aucun moyen d'obtenir un accès d'administration n'est disponible (sudo -A, pkexec)."
+ ],
  "No results found": [
   null,
   "Aucun résultat trouvé"
@@ -702,6 +730,10 @@ window.cockpit_po = {
   null,
   "Pizza Box"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Veuillez vous authentifier pour obtenir un accès administrateur"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Veuillez activer JavaScript pour utiliser la console Web."
@@ -718,6 +750,10 @@ window.cockpit_po = {
   null,
   "Présent"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Problème pour devenir administrateur"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "L’invite via ssh-add a expiré"
@@ -862,6 +898,14 @@ window.cockpit_po = {
   null,
   "Sub-Notebook"
  ],
+ "Switch to administrative access": [
+  null,
+  "Passer à l’accès administrateur"
+ ],
+ "Switch to limited access": [
+  null,
+  "Passer en accès limité"
+ ],
  "Synchronized": [
   null,
   "Synchronisé"
@@ -998,6 +1042,10 @@ window.cockpit_po = {
   null,
   "Synchronisation avec $0 en cours d'essai"
  ],
+ "Turn on administrative access": [
+  null,
+  "Activez l’accès administrateur"
+ ],
  "Unable to connect to that address": [
   null,
   "Impossible de se connecter à cette adresse"
@@ -1074,10 +1122,18 @@ window.cockpit_po = {
   null,
   "Vous vous connectez à $0 pour la première fois."
  ],
+ "You now have administrative access.": [
+  null,
+  "Vous avez l’accès administrateur."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "Votre navigateur n’autorise pas le collage à partir du menu contextuel. Vous pouvez utiliser Maj+Insérer."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Votre navigateur se souviendra de votre niveau d’accès d’une session à l’autre."
+ ],
  "Your session has been terminated.": [
   null,
   "Votre session a été interrompue."
