@@ -132,6 +132,10 @@ window.cockpit_po = {
   null,
   "Cockpit Web コンソールでの管理"
  ],
+ "Administrative access": [
+  null,
+  "管理アクセス"
+ ],
  "Advanced TCA": [
   null,
   "高度な TCA"
@@ -148,6 +152,10 @@ window.cockpit_po = {
   null,
   "Ansible ロールのドキュメント"
  ],
+ "Authenticate": [
+  null,
+  "認証する"
+ ],
  "Authentication": [
   null,
   "認証"
@@ -492,6 +500,18 @@ window.cockpit_po = {
   null,
   "もっと詳しく"
  ],
+ "Limit access": [
+  null,
+  "アクセスの制限"
+ ],
+ "Limited access": [
+  null,
+  "制限付きアクセス"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "限定アクセスモードでは、管理者権限が制限されます。Web コンソールの一部の機能が低下します。"
+ ],
  "Loading system modifications...": [
   null,
   "システム変更をロード中..."
@@ -552,6 +572,10 @@ window.cockpit_po = {
   null,
   "ログインしているユーザーへのメッセージ"
  ],
+ "Method": [
+  null,
+  "方法"
+ ],
  "Mini PC": [
   null,
   "ミニ PC"
@@ -588,6 +612,10 @@ window.cockpit_po = {
   null,
   "遅延なし"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  ""
+ ],
  "No results found": [
   null,
   "結果が見つかりません"
@@ -696,6 +724,10 @@ window.cockpit_po = {
   null,
   "ピザ箱"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "管理者アクセスを得るために認証を行ってください"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Web コンソールを使用するには JavaScript を有効にしてください。"
@@ -712,6 +744,10 @@ window.cockpit_po = {
   null,
   "存在"
  ],
+ "Problem becoming administrator": [
+  null,
+  "管理者への切り替えに問題が発生しました"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "ssh-add によるプロンプトがタイムアウトしました"
@@ -856,6 +892,14 @@ window.cockpit_po = {
   null,
   "サブノート"
  ],
+ "Switch to administrative access": [
+  null,
+  "管理者アクセスへの切り替え"
+ ],
+ "Switch to limited access": [
+  null,
+  "アクセス制限への切り替え"
+ ],
  "Synchronized": [
   null,
   "同期済み"
@@ -992,6 +1036,10 @@ window.cockpit_po = {
   null,
   "$0 との同期を試行中です"
  ],
+ "Turn on administrative access": [
+  null,
+  "管理者アクセスをオンにする"
+ ],
  "Unable to connect to that address": [
   null,
   "そのアドレスに接続できません"
@@ -1068,10 +1116,18 @@ window.cockpit_po = {
   null,
   "初めて $0 に接続しています。"
  ],
+ "You now have administrative access.": [
+  null,
+  "これで管理者アクセスが可能になりました。"
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "お使いのブラウザーでは、コンテキストメニューからの貼り付けが許可されていません。Shift+Insert を使用できます。"
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "ブラウザーはセッション間のアクセスレベルを記憶します。"
+ ],
  "Your session has been terminated.": [
   null,
   "セッションが終了しました。"
