@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Cockput ვებ კონსოლით ადმინისტრირება"
  ],
+ "Administrative access": [
+  null,
+  "ადმინისტრატიული წვდომა"
+ ],
  "Advanced TCA": [
   null,
   "დამატებითი TCA"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Ansible-ის როლების დოკუმენტაცია"
  ],
+ "Authenticate": [
+  null,
+  "ავთენტიკაცია"
+ ],
  "Authentication": [
   null,
   "ავთენტიკაცია"
@@ -320,7 +328,7 @@ window.cockpit_po = {
  ],
  "Copy to clipboard": [
   null,
-  "ბაფერში კოპირება"
+  "ბუფერში კოპირება"
  ],
  "Create $0": [
   null,
@@ -498,6 +506,18 @@ window.cockpit_po = {
   null,
   "გაიგეთ მეტი"
  ],
+ "Limit access": [
+  null,
+  "წვდომის შეზღუდვა"
+ ],
+ "Limited access": [
+  null,
+  "შეზღუდული წვდომა"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "შეზღუდული წვდომა გისაზღვრავთ ადმინისტრატიულ პრივილეგიებს. ვებ კონსოლის ზოგიერთი ნაწილი შეზღუდული იქნება."
+ ],
  "Loading system modifications...": [
   null,
   "სისტემის ცვლილებების ჩატვირთვა..."
@@ -558,6 +578,10 @@ window.cockpit_po = {
   null,
   "შესული მომხმარებლებისთვის შეტყობინების გაგზავნა"
  ],
+ "Method": [
+  null,
+  "მეთოდი"
+ ],
  "Mini PC": [
   null,
   "მინი PC"
@@ -594,6 +618,10 @@ window.cockpit_po = {
   null,
   "დაყოვნების გარეშე"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  "ადმინისტრატორის წვდომის მიღების მეთოდები (sudo -A, pkexec) ხელმისაწვდომი არაა."
+ ],
  "No results found": [
   null,
   "შედეგები ნაპოვნი არაა"
@@ -702,6 +730,10 @@ window.cockpit_po = {
   null,
   "პიცისყუთი"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "ადმინისტრატორი წვდომის მისაღებად გთხოვთ გაიაროთ ავთენტიკაცია"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "ვებ კონსოლის გამოსაყენებლად საჭიროა JavaScript-ის ჩართვა."
@@ -718,6 +750,10 @@ window.cockpit_po = {
   null,
   "წარმოდგენილია"
  ],
+ "Problem becoming administrator": [
+  null,
+  "ადმინისტრატორად გახდომის შეცდომა"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "მოთხოვნას ssh-add-ის გავლით დრო გაუვიდა"
@@ -862,6 +898,14 @@ window.cockpit_po = {
   null,
   "ქვე-ნოუთბუქი"
  ],
+ "Switch to administrative access": [
+  null,
+  "ადმინისტრატორის წვდომაზე გადართვა"
+ ],
+ "Switch to limited access": [
+  null,
+  "შეზღუდულ წვდომებზე გადართვა"
+ ],
  "Synchronized": [
   null,
   "სინქრონიზებულია"
@@ -986,10 +1030,6 @@ window.cockpit_po = {
   null,
   "კომპიუტერის კორპუსი"
  ],
- "Transient packageless sessions require the same operating system and version, for compatibility reasons: $0.": [
-  null,
-  "შუალედურ უპაკეტო სესიებს იგივე ოპერაციული სისტემა და ვერსია სჭირდება თავსებადობისთვის: $0."
- ],
  "Trust and add host": [
   null,
   "ჰოსტის ნდობა და დამატება"
@@ -1002,6 +1042,10 @@ window.cockpit_po = {
   null,
   "$0-თან სინქრონიზაციის მცდელობა"
  ],
+ "Turn on administrative access": [
+  null,
+  "ადმინისტრატორის წვდომების ჩართვა"
+ ],
  "Unable to connect to that address": [
   null,
   "მისამართზე დაკავშირების შეცდომა"
@@ -1022,6 +1066,10 @@ window.cockpit_po = {
   null,
   "უცნობი ჰოსტი: $0"
  ],
+ "Unsupported shell. Check the journal for details.": [
+  null,
+  "მხარდაუჭერელი გარსი. დეტალებისთვის შეამოწმეთ ჟურნალი."
+ ],
  "Untrusted host": [
   null,
   "არასანდო ჰოსტი"
@@ -1074,10 +1122,18 @@ window.cockpit_po = {
   null,
   "$0-ს პირველად უკავშირდებით."
  ],
+ "You now have administrative access.": [
+  null,
+  "ახლა გაქვთ ადმინისტრატორის წვდომა."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "თქვენს ბრაუზერს არ გააჩნია კონტექსტური მენიუდან ჩასმის მხარდაჭერა. სცადეთ დააჭიროთ Shift+Insert-ს."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "თქვენი ბრაუზერი თქვენი წვდომის დონეებს სესიებს შორისაც დაიმახსოვრებს."
+ ],
  "Your session has been terminated.": [
   null,
   "თქვენი სესია გაწყვეტილია."
