@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Beheer met Cockpit Web Console"
  ],
+ "Administrative access": [
+  null,
+  "Administratieve toegang"
+ ],
  "Advanced TCA": [
   null,
   "Geavanceerde TCA"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Ansible rollen documentatie"
  ],
+ "Authenticate": [
+  null,
+  "Authenticatie uitvoeren"
+ ],
  "Authentication": [
   null,
   "Authenticatie"
@@ -482,6 +490,18 @@ window.cockpit_po = {
   null,
   "Kom meer te weten"
  ],
+ "Limit access": [
+  null,
+  "Beperk toegang"
+ ],
+ "Limited access": [
+  null,
+  "Beperkte toegang"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "De beperkte toegangsmodus beperkt de beheerdersrechten. Sommige delen van de webconsole hebben een verminderde functionaliteit."
+ ],
  "Loading system modifications...": [
   null,
   "Systeemwijzigingen laden..."
@@ -542,6 +562,10 @@ window.cockpit_po = {
   null,
   "Bericht aan ingelogde gebruikers"
  ],
+ "Method": [
+  null,
+  "Methode"
+ ],
  "Mini PC": [
   null,
   "Mini PC"
@@ -578,6 +602,10 @@ window.cockpit_po = {
   null,
   "Geen vertraging"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  ""
+ ],
  "No results found": [
   null,
   "Geen resultaten gevonden"
@@ -686,6 +714,10 @@ window.cockpit_po = {
   null,
   "Pizzadoos"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Authenticeer om administratieve toegang te krijgen"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Zet JavaScript aan om de Webconsole te gebruiken."
@@ -702,6 +734,10 @@ window.cockpit_po = {
   null,
   "Aanwezig"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Probleem om beheerder te worden"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "Vragen via ssh-add is verlopen"
@@ -830,6 +866,14 @@ window.cockpit_po = {
   null,
   "Sub-notebook"
  ],
+ "Switch to administrative access": [
+  null,
+  "Schakel om naar beheerderstoegang"
+ ],
+ "Switch to limited access": [
+  null,
+  "Schakel over naar beperkte toegang"
+ ],
  "Synchronized": [
   null,
   "Gesynchroniseerd"
@@ -962,6 +1006,10 @@ window.cockpit_po = {
   null,
   "Bezig met synchroniseren met $0"
  ],
+ "Turn on administrative access": [
+  null,
+  "Schakel beheerderstoegang in"
+ ],
  "Unable to connect to that address": [
   null,
   "Kan niet verbinden met dat adres"
@@ -1034,10 +1082,18 @@ window.cockpit_po = {
   null,
   "Je maakt voor de eerste keer verbinding met $0."
  ],
+ "You now have administrative access.": [
+  null,
+  "Je hebt nu administratieve toegang."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "Je browser staat plakken vanuit het contextmenu niet toe. Je kunt Shift+Insert gebruiken."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Je browser onthoudt je toegangsniveau tijdens sessies."
+ ],
  "Your session has been terminated.": [
   null,
   "Je sessie is beëindigd."
