@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Administração com o Console Web do Cockpit"
  ],
+ "Administrative access": [
+  null,
+  "Acesso administrativo"
+ ],
  "Advanced TCA": [
   null,
   "TCA avançado"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Documentação de papéis do Ansible"
  ],
+ "Authenticate": [
+  null,
+  "Autenticar"
+ ],
  "Authentication": [
   null,
   "Autenticação"
@@ -498,6 +506,18 @@ window.cockpit_po = {
   null,
   "Saiba mais"
  ],
+ "Limit access": [
+  null,
+  "Limitar acesso"
+ ],
+ "Limited access": [
+  null,
+  "Acesso limitado"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "O modo de acesso limitado restringe os privilégios administrativos. Algumas partes do console web terão funcionalidade reduzida."
+ ],
  "Loading system modifications...": [
   null,
   "Carregando modificações do sistema..."
@@ -558,6 +578,10 @@ window.cockpit_po = {
   null,
   "Mensagem para usuários logados"
  ],
+ "Method": [
+  null,
+  "Método"
+ ],
  "Mini PC": [
   null,
   "Mini PC"
@@ -594,6 +618,10 @@ window.cockpit_po = {
   null,
   "Sem Atraso"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  ""
+ ],
  "No results found": [
   null,
   "Nenhum resultado encontrado"
@@ -702,6 +730,10 @@ window.cockpit_po = {
   null,
   "Servidor compacto"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Autentique-se para obter acesso administrativo"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Habilite JavaScript para usar o console web."
@@ -718,6 +750,10 @@ window.cockpit_po = {
   null,
   "Presente"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Problema ao se tornar administrador"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "A solicitação via ssh-add expirou"
@@ -862,6 +898,14 @@ window.cockpit_po = {
   null,
   "Sub notebook"
  ],
+ "Switch to administrative access": [
+  null,
+  "Trocar para acesso administrativo"
+ ],
+ "Switch to limited access": [
+  null,
+  "Trocar para acesso limitado"
+ ],
  "Synchronized": [
   null,
   "Sincronizado"
@@ -998,6 +1042,10 @@ window.cockpit_po = {
   null,
   "Tentando sincronizar com $0"
  ],
+ "Turn on administrative access": [
+  null,
+  "Habilitar acesso administrativo"
+ ],
  "Unable to connect to that address": [
   null,
   "Não é possível conectar a esse endereço"
@@ -1074,10 +1122,18 @@ window.cockpit_po = {
   null,
   "Você está se conectando com $0 pela primeira vez."
  ],
+ "You now have administrative access.": [
+  null,
+  "Agora você tem acesso administrativo."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "Seu navegador não permite colar texto pelo menu de contexto. Você pode usar Shift+Insert."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Seu navegador irá memorizar seu nível de acesso entre as sessões."
+ ],
  "Your session has been terminated.": [
   null,
   "Sua sessão foi encerrada."
