@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Cockpit Web Konsolu ile Yönetim"
  ],
+ "Administrative access": [
+  null,
+  "Yönetimsel erişim"
+ ],
  "Advanced TCA": [
   null,
   "Gelişmiş TCA"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Ansible rolleri belgeleri"
  ],
+ "Authenticate": [
+  null,
+  "Kimlik doğrula"
+ ],
  "Authentication": [
   null,
   "Kimlik doğrulama"
@@ -498,6 +506,18 @@ window.cockpit_po = {
   null,
   "Daha fazla bilgi edinin"
  ],
+ "Limit access": [
+  null,
+  "Erişimi sınırla"
+ ],
+ "Limited access": [
+  null,
+  "Sınırlı erişim"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "Sınırlı erişim kipi, yönetimsel yetkileri kısıtlar. Web konsolunun bazı kısımları sınırlı işlevselliğe sahip olacaktır."
+ ],
  "Loading system modifications...": [
   null,
   "Sistem değişiklikleri yükleniyor..."
@@ -558,6 +578,10 @@ window.cockpit_po = {
   null,
   "Oturum açmış kullanıcılar için ileti"
  ],
+ "Method": [
+  null,
+  "Yöntem"
+ ],
  "Mini PC": [
   null,
   "Mini PC"
@@ -594,6 +618,10 @@ window.cockpit_po = {
   null,
   "Gecikme yok"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  "Yönetimsel erişim elde etmek için hiçbir yöntem mevcut değil (sudo -A, pkexec)."
+ ],
  "No results found": [
   null,
   "Bulunan sonuçlar yok"
@@ -702,6 +730,10 @@ window.cockpit_po = {
   null,
   "Pizza box"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Lütfen yönetimsel erişim elde etmek için kimlik doğrulayın"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Web Konsolunu kullanmak için lütfen JavaScript'i etkinleştirin."
@@ -718,6 +750,10 @@ window.cockpit_po = {
   null,
   "Mevcut"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Yönetici olma sorunu"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "ssh-add aracılığıyla sorma zaman aşımına uğradı"
@@ -862,6 +898,14 @@ window.cockpit_po = {
   null,
   "Alt Dizüstü"
  ],
+ "Switch to administrative access": [
+  null,
+  "Yönetimsel erişime geç"
+ ],
+ "Switch to limited access": [
+  null,
+  "Sınırlı erişime geç"
+ ],
  "Synchronized": [
   null,
   "Eşitlendi"
@@ -986,10 +1030,6 @@ window.cockpit_po = {
   null,
   "Tower"
  ],
- "Transient packageless sessions require the same operating system and version, for compatibility reasons: $0.": [
-  null,
-  "Geçici paketsiz oturumlar, uyumluluk nedenleriyle aynı işletim sistemi ve sürümünü gerektirir: $0."
- ],
  "Trust and add host": [
   null,
   "Anamakineye güven ve ekle"
@@ -1002,6 +1042,10 @@ window.cockpit_po = {
   null,
   "$0 ile eşitlemeye çalışılıyor"
  ],
+ "Turn on administrative access": [
+  null,
+  "Yönetimsel erişimi aç"
+ ],
  "Unable to connect to that address": [
   null,
   "Bu adrese bağlanılamıyor"
@@ -1022,6 +1066,10 @@ window.cockpit_po = {
   null,
   "Bilinmeyen anamakine: $0"
  ],
+ "Unsupported shell. Check the journal for details.": [
+  null,
+  "Desteklenmeyen kabuk. Ayrıntılar için günlüğü gözden geçirin."
+ ],
  "Untrusted host": [
   null,
   "Güvenilmeyen anamakine"
@@ -1074,10 +1122,18 @@ window.cockpit_po = {
   null,
   "İlk kez $0 için bağlanıyorsunuz."
  ],
+ "You now have administrative access.": [
+  null,
+  "Artık yönetimsel erişiminiz var."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "Tarayıcınız, bağlam menüsünden yapıştırmaya izin vermiyor. Shift+Insert kullanabilirsiniz."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Tarayıcınız, oturumlar arasında erişim seviyenizi hatırlayacaktır."
+ ],
  "Your session has been terminated.": [
   null,
   "Oturumunuz sonlandırıldı."
