@@ -144,6 +144,10 @@ window.cockpit_po = {
   null,
   "Адміністрування за допомогою вебконсолі Cockpit"
  ],
+ "Administrative access": [
+  null,
+  "Адміністративний доступ"
+ ],
  "Advanced TCA": [
   null,
   "Розширене TCA"
@@ -160,6 +164,10 @@ window.cockpit_po = {
   null,
   "Документація з ролей Ansible"
  ],
+ "Authenticate": [
+  null,
+  "Розпізнавання"
+ ],
  "Authentication": [
   null,
   "Розпізнавання"
@@ -504,6 +512,18 @@ window.cockpit_po = {
   null,
   "Докладніше"
  ],
+ "Limit access": [
+  null,
+  "Обмежити доступ"
+ ],
+ "Limited access": [
+  null,
+  "Обмежений доступ"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "Модель із обмеженим доступом обмежує адміністративні привілеї. Функціональні можливості деяких частин вебконсолі буде суттєво зменшено."
+ ],
  "Loading system modifications...": [
   null,
   "Завантажуємо модифікації системи…"
@@ -564,6 +584,10 @@ window.cockpit_po = {
   null,
   "Повідомлення користувачам, які увійшли"
  ],
+ "Method": [
+  null,
+  "Метод"
+ ],
  "Mini PC": [
   null,
   "Міні-ПК"
@@ -600,6 +624,10 @@ window.cockpit_po = {
   null,
   "Без затримки"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  "Немає доступних методів отримання адміністративного доступу (sudo -A, pkexec)."
+ ],
  "No results found": [
   null,
   "Нічого не знайдено"
@@ -708,6 +736,10 @@ window.cockpit_po = {
   null,
   "З коробку для піци"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Будь ласка, пройдіть розпізнавання, щоб отримати адміністративний доступ"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Щоб мати змогу користуватися вебконсоллю, будь ласка, увімкніть JavaScript."
@@ -724,6 +756,10 @@ window.cockpit_po = {
   null,
   "Поточна"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Проблеми із набуттям прав адміністратора"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "Час очікування відповіді на запит за допомогою ssh-add вичерпано"
@@ -868,6 +904,14 @@ window.cockpit_po = {
   null,
   "Підноутбук"
  ],
+ "Switch to administrative access": [
+  null,
+  "Перемкнутися на адміністративний доступ"
+ ],
+ "Switch to limited access": [
+  null,
+  "Перемкнутися на обмежений доступ"
+ ],
  "Synchronized": [
   null,
   "Синхронізовано"
@@ -1004,6 +1048,10 @@ window.cockpit_po = {
   null,
   "Намагаємося синхронізуватися з $0"
  ],
+ "Turn on administrative access": [
+  null,
+  "Увімкнути адміністративний доступ"
+ ],
  "Unable to connect to that address": [
   null,
   "Не вдалося встановити з’єднання із цією адресою"
@@ -1080,10 +1128,18 @@ window.cockpit_po = {
   null,
   "Ви вперше встановлюєте з'єднання із $0."
  ],
+ "You now have administrative access.": [
+  null,
+  "Тепер ви маєте адміністративний доступ."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "У вашій програмі для перегляду не передбачено можливості вставлення з контекстного меню. Ви можете скористатися для вставлення комбінацією Shift+Insert."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Ваш браузер запам'ятовуватиме ваш рівень доступу між сеансами."
+ ],
  "Your session has been terminated.": [
   null,
   "Ваш сеанс перервано."
